==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/embed/StateChangeInProgressException.hpp <==
#ifndef _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HPP_
#define _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HDL_
#include "com/sun/star/embed/StateChangeInProgressException.hdl"
#endif

#ifndef _COM_SUN_STAR_EMBED_WRONGSTATEEXCEPTION_HPP_
#include "com/sun/star/embed/WrongStateException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace embed {

inline StateChangeInProgressException::StateChangeInProgressException() SAL_THROW( () )
    : ::com::sun::star::embed::WrongStateException()
    , TargetState(0)
{ }

inline StateChangeInProgressException::StateChangeInProgressException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::sal_Int32& TargetState_) SAL_THROW( () )
    : ::com::sun::star::embed::WrongStateException(Message_, Context_)
    , TargetState(TargetState_)
{ }

StateChangeInProgressException::StateChangeInProgressException(StateChangeInProgressException const & the_other): ::com::sun::star::embed::WrongStateException(the_other), TargetState(the_other.TargetState) {}

StateChangeInProgressException::~StateChangeInProgressException() {}

StateChangeInProgressException & StateChangeInProgressException::operator =(StateChangeInProgressException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::embed::WrongStateException::operator =(the_other);
    TargetState = the_other.TargetState;
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::embed::StateChangeInProgressException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.embed.StateChangeInProgressException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/embed/StateChangeInProgressException.hpp <==
#ifndef _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HPP_
#define _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HDL_
#include "com/sun/star/embed/StateChangeInProgressException.hdl"
#endif

#ifndef _COM_SUN_STAR_EMBED_WRONGSTATEEXCEPTION_HPP_
#include "com/sun/star/embed/WrongStateException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace embed {

inline StateChangeInProgressException::StateChangeInProgressException() SAL_THROW( () )
    : ::com::sun::star::embed::WrongStateException()
    , TargetState(0)
{ }

inline StateChangeInProgressException::StateChangeInProgressException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::sal_Int32& TargetState_) SAL_THROW( () )
    : ::com::sun::star::embed::WrongStateException(Message_, Context_)
    , TargetState(TargetState_)
{ }

StateChangeInProgressException::StateChangeInProgressException(StateChangeInProgressException const & the_other): ::com::sun::star::embed::WrongStateException(the_other), TargetState(the_other.TargetState) {}

StateChangeInProgressException::~StateChangeInProgressException() {}

StateChangeInProgressException & StateChangeInProgressException::operator =(StateChangeInProgressException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::embed::WrongStateException::operator =(the_other);
    TargetState = the_other.TargetState;
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace embed {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::embed::StateChangeInProgressException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.embed.StateChangeInProgressException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::embed::StateChangeInProgressException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::embed::StateChangeInProgressException >::get();
}

#endif // _COM_SUN_STAR_EMBED_STATECHANGEINPROGRESSEXCEPTION_HPP_
